bayespy.inference.vmp.nodes.gaussian.GaussianToGaussianGammaISO.lower_bound_contribution
========================================================================================

.. currentmodule:: bayespy.inference.vmp.nodes.gaussian

.. automethod:: GaussianToGaussianGammaISO.lower_bound_contribution